# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-20 13:47
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_resized.forms
import ovp_uploads.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ovp_uploads', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='UploadedImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to=ovp_uploads.models.ImageName(), verbose_name='Image 350x260')),
                ('image_small', django_resized.forms.ResizedImageField(blank=True, default=None, null=True, upload_to=ovp_uploads.models.ImageName('-small'))),
                ('image_medium', django_resized.forms.ResizedImageField(blank=True, default=None, null=True, upload_to=ovp_uploads.models.ImageName('-medium'))),
                ('image_large', django_resized.forms.ResizedImageField(blank=True, default=None, null=True, upload_to=ovp_uploads.models.ImageName('-large'))),
                ('created_date', models.DateTimeField(auto_now_add=True)),
                ('modified_date', models.DateTimeField(auto_now=True)),
                ('user', models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'uploaded image',
                'verbose_name_plural': 'uploaded images',
            },
        ),
    ]
