# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-24 19:59
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_uploads', '0002_uploadedimage'),
    ]

    operations = [
        migrations.AddField(
            model_name='uploadedimage',
            name='uuid',
            field=models.CharField(blank=True, default=None, max_length=36, verbose_name='UUID'),
        ),
    ]
